//**************************************************************************
//
//  Title: BASE.C
//
//  Author: Jim Cash
//  Version: 1.2
//  Revision History:
//    Original version: June 5, 1990
//    v1.1: February 13, 1991
//    v1.2: June 21, 1991
//
//  LAB #04
//
//  Purpose:
//      This is LAB03 with a real Window background & a stock Icon and
//      Cursor.
//
//**************************************************************************
#define DEBUGGING
//#define DEBUGMSGS
#define _WINDOWS
#include <WINDOWS.H>
#include "BASE.H"
#include <GENLIB.H>

//*------------------------------------------------------------------------
//| Global Variables
//*------------------------------------------------------------------------
HWND    hWnd1;
char    szClassName[] = "OVERLAPPED:1";
char    szAppName[] = "BASE";

//*------------------------------------------------------------------------
//| WinMain:
//|     Parameters:
//|         hInstance     - Handle to current Data Segment
//|         hPrevInstance - Handle to previous Data Segment (NULL if none)
//|         lpszCmdLine   - Long pointer to command line info
//|         nCmdShow      - Integer value specifying how to start app.,
//|                            (Iconic [7] or Normal [1,5])
//*------------------------------------------------------------------------
int PASCAL WinMain (HANDLE hInstance,
                    HANDLE hPrevInstance,
                    LPSTR  lpszCmdLine,
                    int    nCmdShow)
{
int nReturn;

    if (Init(hInstance, hPrevInstance,lpszCmdLine,nCmdShow))
    {
        nReturn = DoMain(hInstance);
        CleanUp();
    }
    return nReturn;
}

//*------------------------------------------------------------------------
//| Init
//|     Initialization for the program is done here:
//|     1)  Register the window class (if this is the first instance)
//|     2)  Create the desktop window for the app.
//|     3)  Show the desktop window in the manner requested by the User.
//|
//*------------------------------------------------------------------------
BOOL Init(HANDLE hInstance,   HANDLE hPrevInstance,
          LPSTR  lpszCmdLine, int    nCmdShow)
{
WNDCLASS    rClass;

    DEBUG("\r\nLAB #04: Sample Name\r\n",0)
    DEBUG("----  Application Initiated  ----\r\n",0)
    DEBUG("hInstance = %04x\r\n",hInstance)
    DEBUG("hPrevInstance = %04x\r\n",hPrevInstance)
    DEBUG("lpszCmdLine = %s\r\n",lpszCmdLine)
    DEBUG("nCmdShow = %04x\r\n",nCmdShow)

    if (!hPrevInstance)
    {
        /*  Register Class for First Overlapped Window  */
        rClass.lpszClassName = szClassName;
        rClass.hInstance     = hInstance;
        rClass.lpfnWndProc   = OverlappedWindowProc1;
        rClass.hCursor       = LoadCursor(NULL,IDC_ARROW);
        rClass.hIcon         = LoadIcon(NULL,IDI_APPLICATION);
        rClass.lpszMenuName  = NULL;
        rClass.hbrBackground = GetStockObject(WHITE_BRUSH);
        rClass.style         = 0L;
        rClass.cbClsExtra    = 0;
        rClass.cbWndExtra    = 0;

        if (!RegisterClass( &rClass))
            return FALSE;
    }

    hWnd1 = CreateWindow(szClassName,
            szAppName,
            WS_OVERLAPPEDWINDOW,
            CW_USEDEFAULT,
            CW_USEDEFAULT,
            CW_USEDEFAULT,
            CW_USEDEFAULT,
            NULL,
            NULL,
            hInstance,
            NULL);

    DEBUG("hWnd1 = %04x\r\n",hWnd1)

    ShowWindow(hWnd1,nCmdShow);

    return hWnd1;
}

//*------------------------------------------------------------------------
//| DoMain:
//|     This is the main loop for the application:
//*------------------------------------------------------------------------
int  DoMain(HANDLE hInstance)
{
MSG msg;

    while (GetMessage(&msg,NULL,0,0))
    {
        TranslateMessage(&msg);
        DispatchMessage(&msg);
    }
    return msg.wParam;
}

//*------------------------------------------------------------------------
//| CleanUp:
//|     Any last-minute application cleanup activities are done here:
//*------------------------------------------------------------------------
void CleanUp(void)
{
    DEBUG("----  Application Terminated ----\r\n",0)
}

//*------------------------------------------------------------------------
//| OverlappedWindowProc1
//|     Parameters:
//|         hWnd    - Handle to Window which message is delivered to.
//|         msgID   - ID number of message
//|         wParam  - 16-bit parameter
//|         lParam  - 32-bit parameter
//|
//*------------------------------------------------------------------------
long FAR PASCAL OverlappedWindowProc1 (HWND     hWnd,
                                       unsigned wMsgID,
                                       WORD     wParam,
                                       LONG     lParam)
{

    DEBUGMSG("O1")
    switch (wMsgID)
    {
    case WM_DESTROY:
        PostQuitMessage(0);
        break;

    default:
        return DefWindowProc(hWnd, wMsgID, wParam, lParam);
    }
    return 0;
}

